=======================
Array Response Function
=======================

The following code block shows how to plot the array transfer function for
beam forming as a function of wavenumber using the ObsPy function
:func:`obspy.signal.array_analysis.array_transff_wavenumber`.

.. plot:: tutorial/code_snippets/array_response_function.py
   :include-source:
